:mod:`tests` module
===================

.. automodule:: tests
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`tests.test_hdf5` module
----------------------------------

.. automodule:: test_hdf5
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`tests.test_freqdemod` module
----------------------------------

.. automodule:: test_freqdemod
    :members:
    :undoc-members:
    :show-inheritance: